@@ -1,4 +1,4 @@
 from .interval import Interval, I
 from .dists import *
-from .pbox import Pbox
+from .pbox import Pbox, env
 from .logic import *
