@@ -85,15 +85,49 @@ class Pbox(object):
             var_right = self.var_right
         )
 
-    def __add__(self, other):
+    def __lt__(self,other):
+        return self.lt(other, method = 'f')
 
+    def __rlt__(self,other):
+        return self.ge(other, method = 'f')
+
+    def __le__(self,other):
+        return self.le(other, method = 'f')
+
+    def __rle__(self,other):
+        return self.gt(other, method = 'f')
+
+    def __gt__(self,other):
+        return self.gt(other, method = 'f')
+
+    def __rgt__(self,other):
+        return self.le(other, method = 'f')
+
+    def __ge__(self,other):
+        return self.ge(other, method = 'f')
+
+    def __rge__(self,other):
+        return self.lt(other, method = 'f')
+
+    def __and__(self, other):
+        return self.logicaland(other, method = 'f')
+
+    def __rand__(self,other):
+        return self.logicaland(other, method = 'f')
+
+    def __or__(self, other):
+        return self.logicalor(other, method = 'f')
+
+    def __ror__(self,other):
+        return self.logicalor(other, method = 'f')
+
+    def __add__(self, other):
         return self.add(other, method = 'f')
 
     def __radd__(self,other):
         return self.add(other, method = 'f')
 
     def __sub__(self,other):
-
         return self.sub(other, method = 'f')
 
     def __rsub__(self,other):
@@ -160,7 +194,61 @@ class Pbox(object):
             self.var_left = left(b)
             self.var_right = right(b)
 
-    ### Public funtions ###
+    ### Public functions ###
+
+    def lt(self, other, method = 'f'):
+	    b = self.add(-other, method)
+	    return(b.get_probability(0))      # return (self.add(-other, method)).get_probability(0)
+
+    def le(self, other, method = 'f'):
+        b = self.add(-other, method)
+        return(b.get_probability(0))      # how is the "or equal to" affecting the calculation?
+
+    def gt(self, other, method = 'f'):
+        self = - self
+        b = self.add(other, method)
+        return(b.get_probability(0))      # maybe 1-prob ?
+
+    def ge(self, other, method = 'f'):
+        self = - self
+        b = self.add(other, method)
+        return(b.get_probability(0))
+
+    def logicaland(self, other, method = 'f'):   # conjunction
+        if      method=='i': return(self.mul(other,method))  # independence a * b
+#        else if method=='p': return(self.min(other,method))  # perfect min(a, b)
+#        else if method=='o': return(max(self.add(other,method)-1, 0))  # opposite max(a + b – 1, 0)
+#        else if method=='+': return(self.min(other,method))  # positive env(a * b, min(a, b))
+#        else if method=='-': return(self.min(other,method))  # negative env(max(a + b – 1, 0), a * b)
+        # otherwise method=='f' :
+        return(env(max(0, self.add(other,method) - 1),  self.min(other,method)))
+
+    def logicalor(self, other, method = 'f'):    # disjunction
+        if      method=='i': return(1 - (1-self) * (1-other))  # independent 1 – (1 – a) * (1 – b)
+#        else if method=='p': return(self.max(other,method))  # perfect max(a, b)
+#        else if method=='o': return(min(self.add(other,method),1)) # opposite min(1, a + b)
+#        else if method=='+': return(env(,min(self.add(other,method),1))  # positive env(max(a, b), 1 – (1 – a) * (1 – b))
+#        else if method=='-': return()  # negative env(1 – (1 – a) * (1 – b), min(1, a + b))
+        # otherwise method=='f' :
+        return(env(self.max(other,method), min(self.add(other,method),1)))
+
+    def env(self, other):
+        if other.__class__.__name__ == 'Interval':
+            other = Pbox(other, steps = self.steps)
+        if other.__class__.__name__ == 'Pbox':
+            if self.steps != other.steps:
+                raise ArithmeticError("Both Pboxes must have the same number of steps")
+
+        nleft  = np.minimum(self.left, other.left)
+        nright = np.maximum(self.right, other.right)
+
+        return Pbox(
+                left    = nleft,
+                right   = nright,
+                steps   = self.steps
+            )
+        return NotImplemented
+
     def add(self, other, method = 'f'):
 
         if method not in ['f','p','o','i']:
@@ -222,7 +310,7 @@ class Pbox(object):
 
         else:
             try:
-                # Try adding constant
+                # Try adding constant
                 if self.shape in ['uniform','normal','cauchy','triangular','skew-normal']:
                     s = self.shape
                 else:
@@ -312,7 +400,7 @@ class Pbox(object):
 
         else:
             try:
-                # Try adding constant
+                # Try adding constant
                 if self.shape in ['uniform','normal','cauchy','triangular','skew-normal']:
                     s = self.shape
                 else:
@@ -349,8 +437,8 @@ class Pbox(object):
         )
 
     def show(self,now = True,**kwargs):
-        # If you want to know why numpy is the WORST thing about numpy
-        # see this code snippet
+        # If you want to know why numpy is the WORST thing about Python
+        # see the get_x code
         left, right = self.get_x()
         y  = self.get_y()
 
@@ -362,6 +450,8 @@ class Pbox(object):
         else:
             return plt
 
+    plot = show
+
     def get_interval(self, *args):
 
         if len(args) == 1:
@@ -427,9 +517,9 @@ class Pbox(object):
     def get_y(self):
         # returns y values for plotting
         return np.append(np.insert(np.linspace(0,1,self.steps),0,0),1)
-# Public functions
 
-# Funcitons
+
+# Functions
 def env_int(*args):
     left = min([min(i) if is_iterable(i) else i for i in args])
     right = max([max(i) if is_iterable(i) else i for i in args])
@@ -515,7 +605,7 @@ def interp_linear(V, steps=200):
     if steps == 1: return np.array([min(V), max(V)])
 
     d = 1 / m
-    n = round(d * steps * 20)
+    n = round(d * steps * 200)
 
     if n == 0:
         c = V
@@ -597,3 +687,6 @@ def straddles(x):
 
 def straddlingzero(x):
     return (left(x) < 0) and (0 < right(x)) # neglects zero as an endpoint
+
+def env(x,y):
+    return x.env(y)
